# -*- coding:utf8 -*-
# import time
# from wqrfproxy import *
#
# start_wqrfproxy()
#
# time.sleep(30)
# try:
#     assert_proxy('http://api.sugg.sogou.com/su','w')
#     assert_proxy('http://api.sugg.sogou.com/su','wangzijia')
# except Exception as e:
#     print(e)
#
# stop_wqrfproxy()
#
# import unittest
#
# class Test(unittest.TestCase):
#     @classmethod
#     def setUpClass(cls):
#         start_wqrfproxy()
#     @classmethod
#     def tearDown(self):
#         stop_wqrfproxy()
#
#     def test_1(self):
#         driver.find_element_by_id('').click()
#         assert_proxy('http;//***.***.com/***/***','userId')

s = 'aaaaaa'

print(s.count('a'))